/*
 * Copyright (C) 2001 Martin Galpin <martin@nemohackers.org>
 */

#ifndef _KUAKEIFACE_H_
#define _KUAKEIFACE_H_

#include <dcopobject.h>

class KuakeIface : virtual public DCOPObject
{
  K_DCOP
public:

k_dcop:
  virtual void setKuakeState() = 0;
};

#endif // _KUAKEIFACE_H_
